==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/DataIntegrationFieldFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link DataIntegrationField}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class DataIntegrationFieldFieldAttributes extends AbstractBeanAttributesDefinition{

    /** dataIntegrationRecordByDataIntegrationRecordId (Database column: DATA_INTEGRATION_RECORD_ID) */
    static public AttributeDefinition dataIntegrationRecordByDataIntegrationRecordId =
        new AttributeDefinition("dataIntegrationRecordByDataIntegrationRecordId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_FIELD")
                .setDatabaseId("DATA_INTEGRATION_RECORD_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.DataIntegrationRecord.class)
                .setLovDataClassKey("id")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.DataIntegrationRecord.class);

    /** fieldId (Database column: FIELD_ID) */
    static public AttributeDefinition fieldId =
        new AttributeDefinition("fieldId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_FIELD")
                .setDatabaseId("FIELD_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_FIELD")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(Long.class);

    /** integrated (Database column: INTEGRATED) */
    static public AttributeDefinition integrated =
        new AttributeDefinition("integrated")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_FIELD")
                .setDatabaseId("INTEGRATED")
                .setMandatory(true)
                .setMaxSize(255)
                .setDefaultValue("0")
                .setType(boolean.class);

    /** dataIntegrationRecordByRelationRecordId (Database column: RELATION_RECORD_ID) */
    static public AttributeDefinition dataIntegrationRecordByRelationRecordId =
        new AttributeDefinition("dataIntegrationRecordByRelationRecordId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_FIELD")
                .setDatabaseId("RELATION_RECORD_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.DataIntegrationRecord.class)
                .setLovDataClassKey("id")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.DataIntegrationRecord.class);

    /** value (Database column: VALUE) */
    static public AttributeDefinition value =
        new AttributeDefinition("value")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_FIELD")
                .setDatabaseId("VALUE")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(dataIntegrationRecordByDataIntegrationRecordId.getName(),dataIntegrationRecordByDataIntegrationRecordId);
        map.put(fieldId.getName(),fieldId);
        map.put(id.getName(),id);
        map.put(integrated.getName(),integrated);
        map.put(dataIntegrationRecordByRelationRecordId.getName(),dataIntegrationRecordByRelationRecordId);
        map.put(value.getName(),value);

        return map;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/DataIntegrationFieldFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link DataIntegrationField}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class DataIntegrationFieldFieldAttributes extends AbstractBeanAttributesDefinition{

    /** dataIntegrationRecordByDataIntegrationRecordId (Database column: DATA_INTEGRATION_RECORD_ID) */
    static public AttributeDefinition dataIntegrationRecordByDataIntegrationRecordId =
        new AttributeDefinition("dataIntegrationRecordByDataIntegrationRecordId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_FIELD")
                .setDatabaseId("DATA_INTEGRATION_RECORD_ID")
                .setMandatory(true)
                .setMaxSize(10)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.DataIntegrationRecord.class)
                .setLovDataClassKey("id")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.DataIntegrationRecord.class);

    /** fieldId (Database column: FIELD_ID) */
    static public AttributeDefinition fieldId =
        new AttributeDefinition("fieldId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_FIELD")
                .setDatabaseId("FIELD_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_FIELD")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(10)
                .setType(Long.class);

    /** integrated (Database column: INTEGRATED) */
    static public AttributeDefinition integrated =
        new AttributeDefinition("integrated")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_FIELD")
                .setDatabaseId("INTEGRATED")
                .setMandatory(true)
                .setMaxSize(1)
                .setTreatAsBoolean(true)
                .setBooleanFalseValue("0")
                .setBooleanTrueValue("1")
                .setDefaultValue("0")
                .setLovFixedList(Arrays.asList(new String[]{"1","0"}))
                .setType(boolean.class);

    /** dataIntegrationRecordByRelationRecordId (Database column: RELATION_RECORD_ID) */
    static public AttributeDefinition dataIntegrationRecordByRelationRecordId =
        new AttributeDefinition("dataIntegrationRecordByRelationRecordId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_FIELD")
                .setDatabaseId("RELATION_RECORD_ID")
                .setMandatory(false)
                .setMaxSize(10)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.DataIntegrationRecord.class)
                .setLovDataClassKey("id")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.DataIntegrationRecord.class);

    /** value (Database column: VALUE) */
    static public AttributeDefinition value =
        new AttributeDefinition("value")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("DATA_INTEGRATION_FIELD")
                .setDatabaseId("VALUE")
                .setMandatory(false)
                .setMaxSize(4000)
                .setType(String.class);

    /**
     * Gets description field.
     *
     * @return the description field
     */
    public static String getDescriptionField()
    {
        return null;
    }

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(dataIntegrationRecordByDataIntegrationRecordId.getName(),dataIntegrationRecordByDataIntegrationRecordId);
        map.put(fieldId.getName(),fieldId);
        map.put(id.getName(),id);
        map.put(integrated.getName(),integrated);
        map.put(dataIntegrationRecordByRelationRecordId.getName(),dataIntegrationRecordByRelationRecordId);
        map.put(value.getName(),value);

        return map;
    }
}
